@@ -3,7 +3,7 @@ from FlaUILibrary.flaui.automation.uia import UIA
 
 
 class UIA2(UIA):
-    """UIA2 window automation module for a centralized communication handling between robot keywords and flaui. """
+    """UIA2 window automation module for a centralized communication handling between robot keywords and Flaui. """
 
     def __init__(self, timeout=1000):
         """
@@ -11,16 +11,18 @@ class UIA2(UIA):
         ``timeout`` is the default waiting value to repeat element find action. Default value is 1000ms.
         """
         super().__init__(timeout)
-        self._automation = UIA2Automation()
-        super().register_action(self._automation)  # pylint: disable=maybe-no-member
+        self._uia2 = UIA2Automation()
+        super().register_action(self._uia2)  # pylint: disable=maybe-no-member
 
     def __del__(self):
         """
-        Destructor to cleanup all C# interfaces
+        Destructor to clean up all C# interfaces
         """
-
-        # C# --> class UIA2Automation : AutomationBase --> abstract class AutomationBase : IDisposable
-        self._automation.Dispose()
+        try:
+            # C# --> class UIA2Automation : AutomationBase --> abstract class AutomationBase : IDisposable
+            self._uia2.Dispose()
+        except TypeError:
+            pass
 
     def identifier(self):
         """
